#!/bin/sh

replace_lang() {
	if [ "$user" = "root" ]; then
		org_file="/etc/X11/xdm/kdmrc"
		new_file="/etc/X11/xdm/kdmrc.new"
		lang=`grep ^Language $org_file 2>/dev/null`
		if [ ! -z $lang ]; then
			sed "s/$lang/Language=$1/" $org_file > $new_file
			mv -f $new_file $org_file
		fi
	fi
}

HEIGHT=15
DIALOG=`which dialog`
if [ -z $DIALOG ]; then
	echo "dialog not found in the system."
	exit 5
fi

user=`whoami`
if [ "$user" != "root" ]; then
	HOMEDIR=`/usr/bin/getent passwd $user | /bin/cut -d: -f6`
	if [ -z $HOMEDIR || -d "$HOMEDIR" ]; then
		$DIALOG --title "Error!" --msgbox "Home directory not found!" 0 0
		exit 5
	fi
	FILE=$HOMEDIR/.i18n
else
	FILE=/etc/sysconfig/i18n
fi

$DIALOG --title "Please select locale of your preference:" --clear \
        --radiolist "" $HEIGHT 50 8 \
	"English (en_US.UTF-8)" "" ON \
	"Simplified Chinese (zh_CN.GB18030)" "" off \
	"Traditional Chinese (zh_TW.big5)" "" off \
	"Japanese (ja_JP.eucJP)" "" off \
	"Japanese (ja_JP.SJIS)" "" off \
	"Japanese (ja_JP.UTF-8)" "" off \
	"Korean (ko_KR.eucKR)" "" off \
	"Korean (ko_KR.UTF-8)" "" off 2>/tmp/test.tmp.$$
retval=$?

choice=`cat /tmp/test.tmp.$$`
rm -f /tmp/checklist.tmp.$$

case $retval in
0)
	case $choice in
	"English (en_US.UTF-8)")
		cat > $FILE <<EOF
LANG="en_US.UTF-8"
SUPPORTED="en_US.UTF-8:en_US:en:zh_CN.GB18030:zh_CN:zh:zh_TW.big5:zh_TW:zh:ja_JP.eucJP:ja_JP:ja:ko_KR.eucKR:ko_KR:ko"
SYSFONT="latarcyrheb-sun16"
EOF
		replace_lang "en_US.UTF-8"
		$DIALOG --title "Done!" --msgbox "Please logout from the system and then login again in order to reflect the changes." 0 0
		;;
	"Simplified Chinese (zh_CN.GB18030)")
		cat > $FILE <<EOF
LANG="zh_CN.GB18030"
LANGUAGE="zh_CN.GB18030:zh_CN.GB2312:zh_CN"
SUPPORTED="en_US.UTF-8:en_US:en:zh_CN.GB18030:zh_CN:zh:zh_TW.big5:zh_TW:zh:ja_JP.eucJP:ja_JP:ja:ko_KR.eucKR:ko_KR:ko"
SYSFONT="lat0-sun16"
SYSFONTACM="8859-15"
EOF
		replace_lang "zh_CN.GB18030"
		$DIALOG --title "Done!" --msgbox "Please logout from the system and then login again in order to reflect the changes." 0 0
		;;
	"Traditional Chinese (zh_TW.big5)")
		cat > $FILE <<EOF
LANG="zh_TW.big5"
LANGUAGE="zh_TW.big5:zh_TW"
SUPPORTED="en_US.UTF-8:en_US:en:zh_CN.GB18030:zh_CN:zh:zh_TW.big5:zh_TW:zh:ja_JP.eucJP:ja_JP:ja:ko_KR.eucKR:ko_KR:ko"
SYSFONT="lat0-sun16"
SYSFONTACM="8859-15"
EOF
		replace_lang "zh_TW.big5"
		$DIALOG --title "Done!" --msgbox "Please logout from the system and then login again in order to reflect the changes." 0 0
		;;
	"Japanese (ja_JP.eucJP)")
		cat > $FILE <<EOF
LANG="ja_JP.eucJP"
LANGUAGE="ja_JP.eucJP:ja_JP"
SUPPORTED="en_US.UTF-8:en_US:en:zh_CN.GB18030:zh_CN:zh:zh_TW.big5:zh_TW:zh:ja_JP.eucJP:ja_JP:ja:ko_KR.eucKR:ko_KR:ko"
SYSFONT="lat0-sun16"
SYSFONTACM="8859-15"
EOF
		replace_lang "ja_JP.eucJP"
		$DIALOG --title "Done!" --msgbox "Please logout first and login again, in order to reflect the changes." 0 0
		;;
	"Japanese (ja_JP.SJIS)")
		cat > $FILE <<EOF
LANG="ja_JP.SJIS"
LANGUAGE="ja_JP.SJIS:ja_JP"
SUPPORTED="en_US.UTF-8:en_US:en:zh_CN.GB18030:zh_CN:zh:zh_TW.big5:zh_TW:zh:ja_JP.eucJP:ja_JP:ja:ko_KR.eucKR:ko_KR:ko"
SYSFONT="lat0-sun16"
SYSFONTACM="8859-15"
EOF
		replace_lang "ja_JP.SJIS"
		$DIALOG --title "Done!" --msgbox "Please logout first and login again, in order to reflect the changes." 0 0
		;;
	"Japanese (ja_JP.UTF-8)")
		cat > $FILE <<EOF
LANG="ja_JP.UTF-8"
LANGUAGE="ja_JP.UTF-8:ja_JP"
SUPPORTED="en_US.UTF-8:en_US:en:zh_CN.GB18030:zh_CN:zh:zh_TW.big5:zh_TW:zh:ja_JP.eucJP:ja_JP:ja:ko_KR.eucKR:ko_KR:ko"
SYSFONT="lat0-sun16"
EOF
		replace_lang "ja_JP.UTF-8"
		$DIALOG --title "Done!" --msgbox "Please logout first and login again, in order to reflect the changes." 0 0
		;;
	"Korean (ko_KR.eucKR)")
		cat > $FILE <<EOF
LANG="ko_KR.eucKR"
LANGUAGE="ko_KR.eucKR:ko_KR"
SUPPORTED="en_US.UTF-8:en_US:en:zh_CN.GB18030:zh_CN:zh:zh_TW.big5:zh_TW:zh:ja_JP.eucJP:ja_JP:ja:ko_KR.eucKR:ko_KR:ko"
SYSFONT="lat0-sun16"
SYSFONTACM="8859-15"
EOF
		replace_lang "ko_KR.eucKR"
		$DIALOG --title "Done!" --msgbox "Please logout from the system and then login again in order to reflect the changes." 0 0
		;;
	"Korean (ko_KR.UTF-8)")
		cat > $FILE <<EOF
LANG="ko_KR.UTF-8"
LANGUAGE="ko_KR.UTF-8:ko_KR"
SUPPORTED="en_US.UTF-8:en_US:en:zh_CN.GB18030:zh_CN:zh:zh_TW.big5:zh_TW:zh:ja_JP.eucJP:ja_JP:ja:ko_KR.eucKR:ko_KR:ko"
SYSFONT="lat0-sun16"
EOF
		replace_lang "ko_KR.UTF-8"
		$DIALOG --title "Done!" --msgbox "Please logout from the system and then login again in order to reflect the changes." 0 0
		;;
	*)
		$DIALOG --title "Error!" --msgbox "Please selece a language!" 0 0
		exit -1
		;;
	esac
	;;
1)
	$DIALOG --title "Information!" --msgbox "Cancel pressed." 0 0
	;;
255)
	$DIALOG --title "Information!" --msgbox "ESC pressed." 0 0
	;;
*)
	;;
esac
